nvector._core.great_circle_distance — nvector 0.7.5 documentation

# nvector._core.great_circle_distance

`great_circle_distance`(n_EA_E, n_EB_E, radius=6371009.0)

  Returns great circle distance between positions A and B

  Parameters
    n_EA_E, n_EB_E: 3 x n array

      > n-vector(s) [no unit] of position A and B, decomposed in E.

      radius: real scalar

        radius of sphere.

      Formulae is given by equation (16) in Gade (2010) and is well conditioned for all angles.